@@ -13,15 +13,15 @@ class ConverterParameters(FormDataModel):
 
 
 class ConverterBase(metaclass=ABCSingleton):
-    """Base class for example plugin used in the tutorial.
-    """
+    """Base class for example plugin used in the tutorial."""
 
     def __init__(self):
         pass
 
     @abc.abstractmethod
-    def convert(self, source: UploadFile, parameters: ConverterParameters) \
-            -> List[Document]:
+    def convert(
+        self, source: UploadFile, parameters: ConverterParameters
+    ) -> List[Document]:
         """Parse the input source file and return a list of documents.
 
         :param source: An UploadFile containing the data.
